@@ -8,9 +8,9 @@ use Role::Tiny::With;
 with 'BorderStyleRole::Source::Hash';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-14'; # DATE
+our $DATE = '2023-07-14'; # DATE
 our $DIST = 'BorderStyle'; # DIST
-our $VERSION = '3.0.2'; # VERSION
+our $VERSION = '3.0.3'; # VERSION
 
 our %BORDER = (
     v => 3,
@@ -107,7 +107,7 @@ BorderStyle::Test::Labeled - A border style that uses labeled characters
 
 =head1 VERSION
 
-This document describes version 3.0.2 of BorderStyle::Test::Labeled (from Perl distribution BorderStyle), released on 2022-02-14.
+This document describes version 3.0.3 of BorderStyle::Test::Labeled (from Perl distribution BorderStyle), released on 2023-07-14.
 
 =head1 SYNOPSIS
 
@@ -286,13 +286,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
